hundun
===================

hundun is a python library for the exploration of chaos.   
Please note that this library is in beta phase.

Installation
------------

hundun can be installed via pip from PyPI.

.. code-block:: bash

    pip install hundun


To use the latest code (unstable), checkout the dev branch and run above command in the main hundun directory.

.. code-block:: bash

    pip install .

Introduction
------------

Under construction.
